=========
Changelog
=========

0.1
~~~

* Initial release - used in production by two major applications at Tangent but
  still quite rough around the edges.  Many features were implemented directly
  in the applications rather than using a feature from oscar.
* Docs are a bit stale and need updating in 0.2

Roadmap
-------

0.2
~~~

Currently a work-in-progress, estimated release date: May 2012.  It will feature:

* Much better documentation, including recipes for common tasks
* Refactoring of shipping methods
* New dashboard functionality for product management, order management, customer services
* New dynamic class loading
* Lots more tests!
* A fully styled sandbox shop based on Twitter's bootstrap.

0.3
~~~

* Rewrite of search app to use Solr and probably not Haystack
* Much better support for variant products which aren't handled very well at the
  moment.
* Dashboard issue management
* Better support for role-based permissions
